==> gs2-cdk-1.0.8.tar.gz: gs2-cdk-1.0.8/src/gs2_cdk/inventory/model/CurrentMasterData.py <==
# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *

from ...core.model import CdkResource, Stack
from .InventoryModel import InventoryModel


class CurrentMasterData(CdkResource):
    version: str= "2019-02-05"
    namespace_name: str
    inventory_models: List[InventoryModel]

    def __init__(
        self,
        stack: Stack,
        namespace_name: str,
        inventory_models: List[InventoryModel],
    ):
        super().__init__(
            "Inventory_CurrentItemModelMaster_" + namespace_name
        )

        self.namespace_name = namespace_name
        self.inventory_models = inventory_models
        stack.add_resource(
            self,
        )

    def alternate_keys(
        self,
    ):
        return self.namespace_name

    def resource_type(
        self,
    ) -> str:
        return "GS2::Inventory::CurrentItemModelMaster"

    def properties(
        self,
    ) -> Dict[str, Any]:
        properties: Dict[str, Any] = {}
        settings: Dict[str, Any] = {}

        settings["version"] = self.version
        if self.inventory_models is not None:
            settings["inventoryModels"] = [
                v.properties(
                )
                for v in self.inventory_models
            ]

        if self.namespace_name is not None:
            properties["NamespaceName"] = self.namespace_name
        if settings is not None:
            properties["Settings"] = settings

        return properties

==> gs2-cdk-1.0.48.tar.gz: gs2-cdk-1.0.48/src/gs2_cdk/inventory/model/CurrentMasterData.py <==
# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *

from ...core.model import CdkResource, Stack
from .InventoryModel import InventoryModel
from .SimpleInventoryModel import SimpleInventoryModel
from .BigInventoryModel import BigInventoryModel


class CurrentMasterData(CdkResource):
    version: str= "2019-02-05"
    namespace_name: str
    inventory_models: List[InventoryModel]
    simple_inventory_models: List[SimpleInventoryModel]
    big_inventory_models: List[BigInventoryModel]

    def __init__(
        self,
        stack: Stack,
        namespace_name: str,
        inventory_models: List[InventoryModel],
        simple_inventory_models: List[SimpleInventoryModel],
        big_inventory_models: List[BigInventoryModel],
    ):
        super().__init__(
            "Inventory_CurrentItemModelMaster_" + namespace_name
        )

        self.namespace_name = namespace_name
        self.inventory_models = inventory_models
        self.simple_inventory_models = simple_inventory_models
        self.big_inventory_models = big_inventory_models
        stack.add_resource(
            self,
        )

    def alternate_keys(
        self,
    ):
        return self.namespace_name

    def resource_type(
        self,
    ) -> str:
        return "GS2::Inventory::CurrentItemModelMaster"

    def properties(
        self,
    ) -> Dict[str, Any]:
        properties: Dict[str, Any] = {}
        settings: Dict[str, Any] = {}

        settings["version"] = self.version
        if self.inventory_models is not None:
            settings["inventoryModels"] = [
                v.properties(
                )
                for v in self.inventory_models
            ]
        if self.simple_inventory_models is not None:
            settings["simpleInventoryModels"] = [
                v.properties(
                )
                for v in self.simple_inventory_models
            ]
        if self.big_inventory_models is not None:
            settings["bigInventoryModels"] = [
                v.properties(
                )
                for v in self.big_inventory_models
            ]

        if self.namespace_name is not None:
            properties["NamespaceName"] = self.namespace_name
        if settings is not None:
            properties["Settings"] = settings

        return properties
